import axios from "axios";

const endpoint = process.env.ENDPOINT;
const username = process.env.USERNAME;
const password = process.env.PASSWORD;
const interval = parseInt( process.env.INTERVAL || '300000');

async function run() {
  console.log('Running');
  const roomsResponse = await axios.get<{
    rooms: {
      roomid: string;
      users: any[];
    }[]
  }>(`${endpoint}/api/getrooms`, {
    params: {
      username: username,
      pass: password
    }
  });

  const rooms = roomsResponse?.data?.rooms || [];
  const zombieRooms = rooms.filter(room => room.users.length === 0);
  console.log(`${rooms.length} rooms found, with ${zombieRooms.length} zombie rooms`);
  if(!zombieRooms.length) {
    return;
  }
  await Promise.all(zombieRooms.map(async room => {
    console.log(`Killing room ${room.roomid}`);
    const kickRes = await axios.get(`${endpoint}/api/message`, {
      params: {
        username: username,
        pass: password,
        kick: room.roomid
      },
      validateStatus: () => true
    });
    console.log(`Room ${room.roomid} killed: ${kickRes.data}`);
  }));
  console.log('Done');
}

async function main() {
  const runWithCatch = async () => { 
    try {
      await run();
    } catch (e) {
      console.error(`Run failed: ${e.message}`);
    }
  }

  await runWithCatch();
  setInterval(runWithCatch, interval);
}
main()
